pywr.parameters.IndexedArrayParameter — Pywr 0.5dev documentation

# pywr.parameters.IndexedArrayParameter

class `pywr.parameters.` `IndexedArrayParameter`

  Parameter which uses an IndexParameter to index an array of Parameters

  An example use of this parameter is to return a demand saving factor (as a float) based on the current demand saving level (calculated by an IndexParameter).

  Parameters: | index_parameter : IndexParameter params : iterable of Parameters or floats

  Notes

  Float arguments params are converted to ConstantParameter

  `__init__`($self, /, *args, **kwargs)

    Initialize self. See help(type(self)) for accurate signature.

  Methods

  `after` |
  `before` |
  `finish` |
  `get_all_values` |
  `get_double_lower_bounds` |
  `get_double_upper_bounds` |
  `get_double_variables` |
  `get_integer_lower_bounds` |
  `get_integer_upper_bounds` |
  `get_integer_variables` |
  `get_value` |
  `load` |
  `lower_bounds` |
  `register` |
  `reset` |
  `set_double_variables` |
  `set_integer_variables` |
  `setup` |
  `unregister` |
  `update` |
  `upper_bounds` |
  `value` | Returns the value of the Parameter at the current index

  Attributes

  `children` |
  `comment` |
  `double_size` |
  `index_parameter` |
  `integer_size` |
  `is_variable` |
  `model` |
  `name` |
  `params` |
  `parents` |
  `size` |